16.149. cdist-type__start_on_boot(7) — cdist 6.9.4 documentation

# 16.149. cdist-type__start_on_boot(7)

## 16.149.1. NAME

cdist-type__start_on_boot - Manage stuff to be started at boot

## 16.149.2. DESCRIPTION

This cdist type allows you to enable or disable stuff to be started at boot of your operating system.

Warning: This type has not been tested intensively and is not fully supported.

## 16.149.3. REQUIRED PARAMETERS

None.

## 16.149.4. OPTIONAL PARAMETERS

state

  Either "present" or "absent", defaults to "present"

target_runlevel

  Runlevel which should be modified, defaults to "default" (only used on gentoo systems).

## 16.149.5. EXAMPLES

    # Ensure snmpd is started at boot
    __start_on_boot snmpd

    # Same, but more explicit
    __start_on_boot snmpd --state present

    # Ensure legacy configuration management will not be started
    __start_on_boot puppet --state absent

## 16.149.6. SEE ALSO

cdist-type__process(7)

## 16.149.7. AUTHORS

Nico Schottelius <nico-cdist--@--schottelius.org>

## 16.149.8. COPYING

Copyright (C) 2012-2019 Nico Schottelius. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.